---
title: <span class="badge object-type-enum"></span> TermsOrder
---
# <span class="badge object-type-enum"></span> TermsOrder

## Definition

```python
class TermsOrder(enum.StrEnum):
    DESC = "desc"
    ASC = "asc"
```
